<?php
	require_once'auxiliares/funcao-slug.php';

	$caminhoAmigavel = slug($_POST['titulo']);

	$selectSlug = mysql_query("SELECT COUNT(id) FROM adm_artigos WHERE SUBSTR(slugArtigo, 1, ".strlen($caminhoAmigavel).") = '".mysql_escape_string($caminhoAmigavel)."'");

	$qtSlugs = mysql_result($selectSlug, 0, 0);

	if($qtSlugs > 0) $caminhoAmigavel .= "-".$qtSlugs;

	include_once("auxiliares/redimensionaImg.class.php");

	$redim = new Redimensiona();

	// Ressolver imagem principal
	$filenameDestaque = null;

	if($_FILES['btnUpload']['size'] > 0){

		$numero = rand(1,99999999);
		$nome = $numero.$_FILES['btnUpload']['name'];
		$nome = $redim->tratar_arquivo_upload($nome);

		$tipoImagem = $_FILES['btnUpload']['type'];

		// Capa
		$fotoCapa = $_FILES['btnUpload']['tmp_name'];
		$filenameCapa = $redim->GerarThumbs($fotoCapa, 48, 47, "imagens-site/galerias/capa", $tipoImagem, $nome);

		// Thumbs
		$fotoThumbs = $_FILES['btnUpload']['tmp_name'];
		$filenameThumbs = $redim->GerarThumbs($fotoThumbs, 188, 93, "imagens-site/galerias/thumbs", $tipoImagem, $nome);

		// Medium
		$fotoMedium = $_FILES['btnUpload']['tmp_name'];
		$filenameMedium = $redim->Redimensionar($fotoMedium, 250, 250, "imagens-site/galerias/medium", $tipoImagem, $nome);

		// Normal
		$foto = $_FILES['btnUpload']['tmp_name'];
		$filenameDestaque = $redim->Redimensionar($foto, 1000, 1000, "imagens-site/galerias", $tipoImagem, $nome);

	}

	$insertQuery = $db->prepare(
		"INSERT INTO adm_artigos
		(titulo,capa,data,resumo,texto,slugArtigo,keywords)
		VALUES (:titulo,:capa,:data,:resumo,:texto,:slugArtigo,:keywords)
	");

	$titulo = $_POST['titulo'];
	$resumo = $_POST['resumo'];
	$texto = $_POST['texto'];
	$keywords = implode(',', $_POST['keywords']);
	$data = date('Y-m-d');

	$insertQuery->bindParam(':titulo', $titulo, PDO::PARAM_STR);
	$insertQuery->bindParam(':capa', $filenameDestaque, PDO::PARAM_STR);
	$insertQuery->bindParam(':resumo', $resumo, PDO::PARAM_STR);
	$insertQuery->bindParam(':texto', $texto, PDO::PARAM_STR);
	$insertQuery->bindParam(':slugArtigo', $caminhoAmigavel, PDO::PARAM_STR);
	$insertQuery->bindParam(':keywords', $keywords, PDO::PARAM_STR);
	$insertQuery->bindParam(':data', $data, PDO::PARAM_STR);

	$insertMarca = $insertQuery->execute();

	$idArtigo = $db->lastInsertId();

	if ($insertMarca) {

		$arrayImagens = array();

		for ($i=0; $i < count($_FILES['fotoGaleriaProduto']['name']); $i++) {

			if ($_FILES['fotoGaleriaProduto']['size'][$i] > 0) {

				$numero = rand(1,99999999);
				$nome = $numero.$_FILES['fotoGaleriaProduto']['name'][$i];
				$nome = $redim->tratar_arquivo_upload($nome);

				$tipoImagem = $_FILES['fotoGaleriaProduto']['type'][$i];

				// Thumbs
				$fotoThumbs = $_FILES['fotoGaleriaProduto']['tmp_name'][$i];
				$filenameGallery = $redim->GerarThumbs($fotoThumbs, 65, 65, "imagens-site/galerias/thumbs", $tipoImagem, $nome);

				// Medium
				$foto = $_FILES['fotoGaleriaProduto']['tmp_name'][$i];
				$filenameGallery = $redim->Redimensionar($foto, 230, 230, "imagens-site/galerias/medium", $tipoImagem, $nome);

				// Normal
				$foto = $_FILES['fotoGaleriaProduto']['tmp_name'][$i];
				$filenameGallery = $redim->Redimensionar($foto, 1000, 1000, "imagens-site/galerias", $tipoImagem, $nome);

				$insertFotosGallery = $db->prepare("INSERT INTO adm_gallery (id_artigo, arquivo) VALUES (:id, :imagem)");
				$insertFotosGallery->bindParam(':id', $idArtigo, PDO::PARAM_STR);
				$insertFotosGallery->bindParam(':imagem', $filenameGallery, PDO::PARAM_STR);
				$insertFotosGallery->execute();

			}

		}

	}
?>

<table>
	<tr>
		<td>
			<?php echo ($insertMarca) ? 'Publicado com sucesso.' : 'Houve um erro ao publicar.'; ?>
			<meta http-equiv="refresh" content="3; url=miolo.php?miolo=galerias&acao=cadastrar" />
		</td>
	</tr>
</table>